@@ -30,19 +30,18 @@
 
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
-#include "version.h"
 
-MainWindow::MainWindow(QWidget *parent, const QString &file) :
-    QDialog(parent),
-    ui(new Ui::MainWindow)
+MainWindow::MainWindow(QWidget *parent, const QString &file)
+    : QDialog(parent)
+    , ui(new Ui::MainWindow)
 {
     debug = (QProcessEnvironment::systemEnvironment().value(QStringLiteral("DEBUG")).length() > 0);
 
-    qDebug().noquote() << QCoreApplication::applicationName() << "version:" << VERSION;
+    qDebug().noquote() << QCoreApplication::applicationName() << "version:" << QCoreApplication::applicationVersion();
     ui->setupUi(this);
     setWindowFlags(Qt::Window); // for the close, min and max buttons
 
-    connect(qApp, &QApplication::aboutToQuit, this, &MainWindow::cleanup);
+    connect(QApplication::instance(), &QApplication::aboutToQuit, this, &MainWindow::cleanup);
 
     file_name = file;
     this->setWindowTitle(tr("MX Conky"));
@@ -51,21 +50,20 @@ MainWindow::MainWindow(QWidget *parent, const QString &file) :
     lua_format = QStringLiteral("^\\s*(--|conky.config\\s*=\\s*{|conky.text\\s*=\\s*{)");
     lua_config = QStringLiteral("^\\s*(conky.config\\s*=\\s*{");
     old_format = QStringLiteral("^\\s*#|^TEXT$");
-    lua_comment_line =QStringLiteral("^\\s*--");
+    lua_comment_line = QStringLiteral("^\\s*--");
     lua_comment_start = QStringLiteral("^\\s*--\\[\\[");
     lua_comment_end = QStringLiteral("^\\s*\\]\\]");
     old_comment_line = QStringLiteral("^\\s*#");
-    capture_lua_color = QStringLiteral("^(?<before>(.*\\]\\])?\\s*(?<color_item>default_color|color\\d)(?:\\s*=\\s*[\\\"\\']))(?:#?)(?<color_value>[[:alnum:]]+)(?<after>(?:[\\\"\\']).*)");
-    capture_old_color = QStringLiteral("^(?<before>\\s*(?<color_item>default_color|color\\d)(?:\\s+))(?:#?)(?<color_value>[[:alnum:]]+)(?<after>.*)");
+    capture_lua_color = QStringLiteral("^(?<before>(.*\\]\\])?\\s*(?<color_item>default_color|color\\d)(?:\\s*=\\s*["
+                                       "\\\"\\']))(?:#?)(?<color_value>[[:alnum:]]+)(?<after>(?:[\\\"\\']).*)");
+    capture_old_color = QStringLiteral(
+        "^(?<before>\\s*(?<color_item>default_color|color\\d)(?:\\s+))(?:#?)(?<color_value>[[:alnum:]]+)(?<after>.*)");
 
     refresh();
     restoreGeometry(settings.value(QStringLiteral("geometery")).toByteArray());
 }
 
-MainWindow::~MainWindow()
-{
-    delete ui;
-}
+MainWindow::~MainWindow() { delete ui; }
 
 // detect conky format old or lua
 void MainWindow::detectConkyFormat()
@@ -74,7 +72,8 @@ void MainWindow::detectConkyFormat()
     QRegularExpression old_format_regexp(old_format);
 
     const QStringList list = file_content.split(QStringLiteral("\n"));
-    if (debug) qDebug() << "Detecting conky format: " + file_name ;
+    if (debug)
+        qDebug() << "Detecting conky format: " + file_name;
 
     conky_format_detected = false;
 
@@ -83,20 +82,21 @@ void MainWindow::detectConkyFormat()
         if (lua_format_match.hasMatch()) {
             is_lua_format = true;
             conky_format_detected = true;
-            if (debug) qDebug() << "Conky format detected 'lua-format' :" + file_name ;
+            if (debug)
+                qDebug() << "Conky format detected 'lua-format' :" + file_name;
             break;
         }
         QRegularExpressionMatch old_format_match = old_format_regexp.match(row);
         if (old_format_match.hasMatch()) {
             is_lua_format = false;
             conky_format_detected = true;
-            if (debug) qDebug() << "Conky format detected 'old-format' :" + file_name ;
+            if (debug)
+                qDebug() << "Conky format detected 'old-format' :" + file_name;
             break;
         }
     }
 }
 
-
 // find defined colors in the config file
 void MainWindow::parseContent()
 {
@@ -111,8 +111,8 @@ void MainWindow::parseContent()
     bool own_window_hints_found = false;
 
     QString comment_sep;
-//    QString block_comment_start = "--[[";
-//    QString block_comment_end = "]]";
+    //    QString block_comment_start = "--[[";
+    //    QString block_comment_end = "]]";
 
     if (is_lua_format) {
         regexp_color = regexp_lua_color;
@@ -124,13 +124,13 @@ void MainWindow::parseContent()
         comment_sep = QStringLiteral("#");
     }
 
-
     const QStringList list = file_content.split(QStringLiteral("\n"));
 
-    if (debug) qDebug() << "Parsing content: " + file_name ;
+    if (debug)
+        qDebug() << "Parsing content: " + file_name;
 
     bool lua_block_comment = false;
-//  bool lua_config = false;
+    //  bool lua_config = false;
     for (const QString &row : list) {
         // lua comment block
         QString trow = row.trimmed();
@@ -138,7 +138,8 @@ void MainWindow::parseContent()
             if (lua_block_comment) {
                 if (trow.endsWith(block_comment_end)) {
                     lua_block_comment = false;
-                    if (debug) qDebug() << "Lua block comment end 'ENDS WITH LINE' found" ;
+                    if (debug)
+                        qDebug() << "Lua block comment end 'ENDS WITH LINE' found";
                     continue;
                 }
                 if (trow.contains(block_comment_end)) {
@@ -147,14 +148,16 @@ void MainWindow::parseContent()
                     ltrow.removeFirst();
                     trow = ltrow.join(block_comment_end);
                     trow = trow.trimmed();
-                    if (debug) qDebug() << "Lua block comment end CONTAINS line found: after ]]: " << trow ;
+                    if (debug)
+                        qDebug() << "Lua block comment end CONTAINS line found: after ]]: " << trow;
                 } else {
                     continue;
                 }
             }
             if (!lua_block_comment) {
                 if (trow.startsWith(block_comment_start)) {
-                   if (debug) qDebug() << "Lua block comment 'STARTS WITH LINE' found" ;
+                    if (debug)
+                        qDebug() << "Lua block comment 'STARTS WITH LINE' found";
                     lua_block_comment = true;
                     continue;
                 }
@@ -163,10 +166,10 @@ void MainWindow::parseContent()
                     QStringList ltrow = trow.split(block_comment_start);
                     trow = ltrow[0];
                     trow = trow.trimmed();
-                    if (debug) qDebug() << "Lua block comment start CONTAINS line found: before start --[[: " << trow ;
+                    if (debug)
+                        qDebug() << "Lua block comment start CONTAINS line found: before start --[[: " << trow;
                 }
             }
-
         }
         // comment line
         if (trow.startsWith(comment_sep))
@@ -194,19 +197,19 @@ void MainWindow::parseContent()
             } else if (color_item == QLatin1String("color4")) {
                 setColor(ui->widgetColor4, strToColor(color_value));
             } else if (color_item == QLatin1String("color5")) {
-                ui->labelColor5->setText(ui->labelColor0->text().replace('0','5'));
+                ui->labelColor5->setText(ui->labelColor0->text().replace('0', '5'));
                 setColor(ui->widgetColor5, strToColor(color_value));
             } else if (color_item == QLatin1String("color6")) {
-                ui->labelColor6->setText(ui->labelColor0->text().replace('0','6'));
+                ui->labelColor6->setText(ui->labelColor0->text().replace('0', '6'));
                 setColor(ui->widgetColor6, strToColor(color_value));
             } else if (color_item == QLatin1String("color7")) {
-                ui->labelColor7->setText(ui->labelColor0->text().replace('0','7'));
+                ui->labelColor7->setText(ui->labelColor0->text().replace('0', '7'));
                 setColor(ui->widgetColor7, strToColor(color_value));
             } else if (color_item == QLatin1String("color8")) {
-                ui->labelColor8->setText(ui->labelColor0->text().replace('0','8'));
+                ui->labelColor8->setText(ui->labelColor0->text().replace('0', '8'));
                 setColor(ui->widgetColor8, strToColor(color_value));
             } else if (color_item == QLatin1String("color9")) {
-                ui->labelColor9->setText(ui->labelColor0->text().replace('0','9'));
+                ui->labelColor9->setText(ui->labelColor0->text().replace('0', '9'));
                 setColor(ui->widgetColor9, strToColor(color_value));
             }
             continue;
@@ -215,7 +218,8 @@ void MainWindow::parseContent()
         // Desktop config
         if (trow.startsWith(QLatin1String("own_window_hints"))) {
             own_window_hints_found = true;
-            if (debug) qDebug() << "own_window_hints line found: " << trow ;
+            if (debug)
+                qDebug() << "own_window_hints line found: " << trow;
             if (trow.contains(QLatin1String("sticky")))
                 ui->radioAllDesktops->setChecked(true);
             else
@@ -240,7 +244,8 @@ void MainWindow::parseContent()
 bool MainWindow::checkConkyRunning()
 {
     int ret = system("sleep 0.3; pgrep -u $(id -nu) -x conky >/dev/null 2>&1");
-    if (debug) qDebug() << system("echo pgrep -u $(id -nu) -x conky : ") << ret;
+    if (debug)
+        qDebug() << system("echo pgrep -u $(id -nu) -x conky : ") << ret;
     if (ret == 0) {
         ui->pushToggleOn->setText(QStringLiteral("Stop"));
         ui->pushToggleOn->setIcon(QIcon::fromTheme(QStringLiteral("stop")));
@@ -268,7 +273,7 @@ bool MainWindow::readFile(const QString &file_name)
 QColor MainWindow::strToColor(const QString &colorstr)
 {
     QColor color(colorstr);
-    if (!color.isValid())  // if color is invalid assume RGB values and add a # in front of the string
+    if (!color.isValid()) // if color is invalid assume RGB values and add a # in front of the string
         color.setNamedColor("#" + colorstr);
     return color;
 }
@@ -278,9 +283,8 @@ void MainWindow::refresh()
     modified = false;
 
     // hide all color frames by default, display only the ones in the config file
-    const QList<QWidget *> frames({ui->frameDefault, ui->frame0, ui->frame1, ui->frame2,
-                                   ui->frame3, ui->frame4, ui->frame5, ui->frame6,
-                                   ui->frame7, ui->frame8, ui->frame9});
+    const QList<QWidget *> frames({ui->frameDefault, ui->frame0, ui->frame1, ui->frame2, ui->frame3, ui->frame4,
+                                   ui->frame5, ui->frame6, ui->frame7, ui->frame8, ui->frame9});
     for (QWidget *w : frames)
         w->hide();
     // draw borders around color widgets
@@ -308,21 +312,24 @@ void MainWindow::refresh()
 void MainWindow::saveBackup()
 {
     if (modified) {
-        int ans = QMessageBox::question(this, QStringLiteral("Backup config file") , QStringLiteral("Do you want to preserve the original file?"));
+        int ans = QMessageBox::question(this, QStringLiteral("Backup config file"),
+                                        QStringLiteral("Do you want to preserve the original file?"));
         if (ans == QMessageBox::Yes) {
             QString time_stamp = cmd.getCmdOut(QStringLiteral("date +%y%m%d_%H%m%S"));
             QFileInfo fi(file_name);
             QString new_name = fi.canonicalPath() + "/" + fi.baseName() + "_" + time_stamp;
-            if (fi.completeSuffix().length() > 0) new_name += "." + fi.completeSuffix();
+            if (fi.completeSuffix().length() > 0)
+                new_name += "." + fi.completeSuffix();
             QFile::copy(file_name + ".bak", new_name);
-            QMessageBox::information(this, QStringLiteral("Backed up config file"), "The original configuration was backed up to " + new_name);
+            QMessageBox::information(this, QStringLiteral("Backed up config file"),
+                                     "The original configuration was backed up to " + new_name);
         }
     }
     QFile(file_name + ".bak").remove();
 }
 
 // write color change back to the file
-void MainWindow::writeColor(QWidget *widget, QColor color)
+void MainWindow::writeColor(QWidget *widget, const QColor &color)
 {
     QRegularExpression regexp_old_comment_line(old_comment_line);
     QRegularExpression regexp_lua_comment_line(lua_comment_line);
@@ -334,8 +341,8 @@ void MainWindow::writeColor(QWidget *widget, QColor color)
     QRegularExpression regexp_comment_line;
 
     QString comment_sep;
-//    QString block_comment_start = "--[[";
-//    QString block_comment_end = "]]";
+    //    QString block_comment_start = "--[[";
+    //    QString block_comment_end = "]]";
 
     if (is_lua_format) {
         regexp_color = regexp_lua_color;
@@ -384,7 +391,8 @@ void MainWindow::writeColor(QWidget *widget, QColor color)
             if (lua_block_comment) {
                 if (trow.endsWith(block_comment_end)) {
                     lua_block_comment = false;
-                    if (debug) qDebug() << "Lua block comment end 'ENDS WITH LINE' found" ;
+                    if (debug)
+                        qDebug() << "Lua block comment end 'ENDS WITH LINE' found";
                     new_list << row;
                     continue;
                 }
@@ -394,7 +402,8 @@ void MainWindow::writeColor(QWidget *widget, QColor color)
                     ltrow.removeFirst();
                     trow = ltrow.join(block_comment_end);
                     trow = trow.trimmed();
-                    if (debug) qDebug() << "Lua block comment end CONTAINS line found: after ]]: " << trow ;
+                    if (debug)
+                        qDebug() << "Lua block comment end CONTAINS line found: after ]]: " << trow;
                 } else {
                     new_list << row;
                     continue;
@@ -402,7 +411,8 @@ void MainWindow::writeColor(QWidget *widget, QColor color)
             }
             if (!lua_block_comment) {
                 if (trow.startsWith(block_comment_start)) {
-                    if (debug) qDebug() << "Lua block comment 'STARTS WITH LINE' found" ;
+                    if (debug)
+                        qDebug() << "Lua block comment 'STARTS WITH LINE' found";
                     lua_block_comment = true;
                     new_list << row;
                     continue;
@@ -412,10 +422,10 @@ void MainWindow::writeColor(QWidget *widget, QColor color)
                     QStringList ltrow = trow.split(block_comment_start);
                     trow = ltrow[0];
                     trow = trow.trimmed();
-                    if (debug) qDebug() << "Lua block comment start CONTAINS line found: before start --[[: " << trow ;
+                    if (debug)
+                        qDebug() << "Lua block comment start CONTAINS line found: before start --[[: " << trow;
                 }
             }
-
         }
         // comment line
         if (trow.startsWith(comment_sep)) {
@@ -424,11 +434,12 @@ void MainWindow::writeColor(QWidget *widget, QColor color)
         }
 
         match_color = regexp_color.match(row);
-        if ( match_color.hasMatch() && match_color.captured(QStringLiteral("color_item")) == item_name ) {
+        if (match_color.hasMatch() && match_color.captured(QStringLiteral("color_item")) == item_name) {
             color_name = color.name();
             if (!is_lua_format)
                 color_name = color.name().remove('#');
-            new_list << match_color.captured(QStringLiteral("before")) + color_name + match_color.captured(QStringLiteral("after"));
+            new_list << match_color.captured(QStringLiteral("before")) + color_name
+                            + match_color.captured(QStringLiteral("after"));
         } else {
             new_list << row;
             continue;
@@ -447,7 +458,7 @@ void MainWindow::writeFile(const QString &file_name, const QString &content)
         file.close();
         modified = true;
     } else {
-        qDebug() << "Error opening file " + file_name  + " for output";
+        qDebug() << "Error opening file " + file_name + " for output";
     }
 }
 
@@ -455,9 +466,8 @@ void MainWindow::cleanup()
 {
     saveBackup();
 
-//    if (!cmd->terminate())
-//        cmd->kill();
-
+    //    if (!cmd->terminate())
+    //        cmd->kill();
 }
 
 void MainWindow::pickColor(QWidget *widget)
@@ -469,7 +479,7 @@ void MainWindow::pickColor(QWidget *widget)
     }
 }
 
-void MainWindow::setColor(QWidget *widget, QColor color)
+void MainWindow::setColor(QWidget *widget, const QColor &color)
 {
     widget->parentWidget()->show();
     if (color.isValid()) {
@@ -480,39 +490,35 @@ void MainWindow::setColor(QWidget *widget, QColor color)
     }
 }
 
-
-void MainWindow::cmdStart()
-{
-    setCursor(QCursor(Qt::BusyCursor));
-}
-
+void MainWindow::cmdStart() { setCursor(QCursor(Qt::BusyCursor)); }
 
 void MainWindow::cmdDone()
 {
- //   ui->progressBar->setValue(ui->progressBar->maximum());
+    //   ui->progressBar->setValue(ui->progressBar->maximum());
     setCursor(QCursor(Qt::ArrowCursor));
-    //cmd->disconnect();
+    // cmd->disconnect();
 }
 
 void MainWindow::setConnections()
 {
-//    connect(cmd, &Cmd::started, this, &MainWindow::cmdStart);
-//    connect(cmd, &Cmd::finished, this, &MainWindow::cmdDone);
+    //    connect(cmd, &Cmd::started, this, &MainWindow::cmdStart);
+    //    connect(cmd, &Cmd::finished, this, &MainWindow::cmdDone);
 }
 
 void MainWindow::on_pushAbout_clicked()
 {
     this->hide();
     const QString url = QStringLiteral("file:///usr/share/doc/mx-conky/license.html");
-    QMessageBox msgBox(QMessageBox::NoIcon,
-                       tr("About MX Conky"), "<p align=\"center\"><b><h2>" +
-                       tr("MX Conky") + "</h2></b></p><p align=\"center\">" + tr("Version: ") + VERSION + "</p><p align=\"center\"><h3>" +
-                       tr("GUI program for configuring Conky in MX Linux") +
-                       "</h3></p><p align=\"center\"><a href=\"http://mxlinux.org\">http://mxlinux.org</a><br /></p><p align=\"center\">" +
-                       tr("Copyright (c) MX Linux") + "<br /><br /></p>");
-    auto btnLicense = msgBox.addButton(tr("License"), QMessageBox::HelpRole);
-    auto btnChangelog = msgBox.addButton(tr("Changelog"), QMessageBox::HelpRole);
-    auto btnCancel = msgBox.addButton(tr("Cancel"), QMessageBox::NoRole);
+    QMessageBox msgBox(QMessageBox::NoIcon, tr("About MX Conky"),
+                       "<p align=\"center\"><b><h2>" + tr("MX Conky") + "</h2></b></p><p align=\"center\">"
+                           + tr("Version: ") + QCoreApplication::applicationVersion() + "</p><p align=\"center\"><h3>"
+                           + tr("GUI program for configuring Conky in MX Linux")
+                           + "</h3></p><p align=\"center\"><a href=\"http://mxlinux.org\">http://mxlinux.org</a><br "
+                             "/></p><p align=\"center\">"
+                           + tr("Copyright (c) MX Linux") + "<br /><br /></p>");
+    auto *btnLicense = msgBox.addButton(tr("License"), QMessageBox::HelpRole);
+    auto *btnChangelog = msgBox.addButton(tr("Changelog"), QMessageBox::HelpRole);
+    auto *btnCancel = msgBox.addButton(tr("Cancel"), QMessageBox::NoRole);
     btnCancel->setIcon(QIcon::fromTheme(QStringLiteral("window-close")));
 
     msgBox.exec();
@@ -523,20 +529,23 @@ void MainWindow::on_pushAbout_clicked()
         else
             system("xdg-open " + url.toUtf8());
     } else if (msgBox.clickedButton() == btnChangelog) {
-        auto changelog = new QDialog(this);
+        auto *changelog = new QDialog(this);
         changelog->setWindowTitle(tr("Changelog"));
-        changelog->resize(600, 500);
+        const auto height {500};
+        const auto width {600};
+        changelog->resize(width, height);
 
-        auto text = new QTextEdit;
+        auto *text = new QTextEdit;
         text->setReadOnly(true);
         Cmd cmd;
-        text->setText(cmd.getCmdOut("zless /usr/share/doc/" + QFileInfo(QCoreApplication::applicationFilePath()).fileName()  + "/changelog.gz"));
+        text->setText(cmd.getCmdOut("zless /usr/share/doc/"
+                                    + QFileInfo(QCoreApplication::applicationFilePath()).fileName() + "/changelog.gz"));
 
-        auto btnClose = new QPushButton(tr("&Close"));
+        auto *btnClose = new QPushButton(tr("&Close"));
         btnClose->setIcon(QIcon::fromTheme(QStringLiteral("window-close")));
         connect(btnClose, &QPushButton::clicked, changelog, &QDialog::close);
 
-        auto layout = new QVBoxLayout;
+        auto *layout = new QVBoxLayout;
         layout->addWidget(text);
         layout->addWidget(btnClose);
         changelog->setLayout(layout);
@@ -556,58 +565,23 @@ void MainWindow::on_pushHelp_clicked()
     system(cmd.toUtf8());
 }
 
+void MainWindow::on_pushDefaultColor_clicked() { pickColor(ui->widgetDefaultColor); }
 
-void MainWindow::on_pushDefaultColor_clicked()
-{
-    pickColor(ui->widgetDefaultColor);
-}
+void MainWindow::on_pushColor0_clicked() { pickColor(ui->widgetColor0); }
 
-void MainWindow::on_pushColor0_clicked()
-{
-    pickColor(ui->widgetColor0);
-}
+void MainWindow::on_pushColor1_clicked() { pickColor(ui->widgetColor1); }
 
-void MainWindow::on_pushColor1_clicked()
-{
-    pickColor(ui->widgetColor1);
-}
+void MainWindow::on_pushColor2_clicked() { pickColor(ui->widgetColor2); }
 
-void MainWindow::on_pushColor2_clicked()
-{
-    pickColor(ui->widgetColor2);
-}
+void MainWindow::on_pushColor3_clicked() { pickColor(ui->widgetColor3); }
 
-void MainWindow::on_pushColor3_clicked()
-{
-    pickColor(ui->widgetColor3);
-}
-
-void MainWindow::on_pushColor4_clicked()
-{
-    pickColor(ui->widgetColor4);
-}
-
-void MainWindow::on_pushColor5_clicked()
-{
-    pickColor(ui->widgetColor5);
-}
-void MainWindow::on_pushColor6_clicked()
-{
-    pickColor(ui->widgetColor6);
-}
-void MainWindow::on_pushColor7_clicked()
-{
-    pickColor(ui->widgetColor7);
-}
-void MainWindow::on_pushColor8_clicked()
-{
-    pickColor(ui->widgetColor8);
-}
-void MainWindow::on_pushColor9_clicked()
-{
-    pickColor(ui->widgetColor9);
-}
+void MainWindow::on_pushColor4_clicked() { pickColor(ui->widgetColor4); }
 
+void MainWindow::on_pushColor5_clicked() { pickColor(ui->widgetColor5); }
+void MainWindow::on_pushColor6_clicked() { pickColor(ui->widgetColor6); }
+void MainWindow::on_pushColor7_clicked() { pickColor(ui->widgetColor7); }
+void MainWindow::on_pushColor8_clicked() { pickColor(ui->widgetColor8); }
+void MainWindow::on_pushColor9_clicked() { pickColor(ui->widgetColor9); }
 
 void MainWindow::on_pushToggleOn_clicked()
 {
@@ -620,7 +594,6 @@ void MainWindow::on_pushToggleOn_clicked()
     checkConkyRunning();
 }
 
-
 void MainWindow::on_pushRestore_clicked()
 {
     if (QFile(file_name + ".bak").exists())
@@ -641,18 +614,23 @@ void MainWindow::on_pushEdit_clicked()
     run += QLatin1String("$(xdg-mime query default text/plain)  2>/dev/null ");
     run += QLatin1String("| head -1 | sed 's/^Exec=//' | tr -d '\"' | tr -s ' ' | sed 's/@@//g; s/%f//I; s/%u//I' ");
     bool quiet = true;
-    if (debug) qDebug() << "run-cmd: " << run;
-    if (debug) quiet = false;
+    if (debug)
+        qDebug() << "run-cmd: " << run;
+    if (debug)
+        quiet = false;
     bool error = cmd.run(run, editor, quiet);
-    if (debug) qDebug() << "run:'" + editor + " '" + file_name.toUtf8() + "'";
+    if (debug)
+        qDebug() << "run:'" + editor + " '" + file_name.toUtf8() + "'";
     if (editor.startsWith(QLatin1String("kate -s")) || editor.startsWith(QLatin1String("kate --start")))
         editor = QStringLiteral("kate");
     if (system(editor.toUtf8() + " '" + file_name.toUtf8() + "'") != 0) {
         if (error || (system("which " + editor.toUtf8() + " 1>/dev/null") != 0)) {
-            if (debug) qDebug() << "no default text editor defined" << editor;
+            if (debug)
+                qDebug() << "no default text editor defined" << editor;
             // try featherpad explicitly
             if (system("which featherpad 1>/dev/null") == 0) {
-                if (debug) qDebug() << "try featherpad text editor " ;
+                if (debug)
+                    qDebug() << "try featherpad text editor ";
                 system("featherpad '" + file_name.toUtf8() + "'");
             }
             refresh();
@@ -667,7 +645,8 @@ void MainWindow::on_pushEdit_clicked()
 void MainWindow::on_pushChange_clicked()
 {
     saveBackup();
-    QString selected = QFileDialog::getOpenFileName(nullptr, QObject::tr("Select Conky Manager config file"), QFileInfo(file_name).path());
+    QString selected = QFileDialog::getOpenFileName(nullptr, QObject::tr("Select Conky Manager config file"),
+                                                    QFileInfo(file_name).path());
     if (!selected.isEmpty())
         file_name = selected;
     refresh();
@@ -701,7 +680,8 @@ void MainWindow::on_radioDesktop1_clicked()
             if (lua_block_comment) {
                 if (trow.endsWith(block_comment_end)) {
                     lua_block_comment = false;
-                    if (debug) qDebug() << "Lua block comment end 'ENDS WITH LINE' found" ;
+                    if (debug)
+                        qDebug() << "Lua block comment end 'ENDS WITH LINE' found";
                     new_list << row;
                     continue;
                 }
@@ -711,7 +691,8 @@ void MainWindow::on_radioDesktop1_clicked()
                     ltrow.removeFirst();
                     trow = ltrow.join(block_comment_end);
                     trow = trow.trimmed();
-                    if (debug) qDebug() << "Lua block comment end CONTAINS line found: after ]]: " << trow ;
+                    if (debug)
+                        qDebug() << "Lua block comment end CONTAINS line found: after ]]: " << trow;
                 } else {
                     new_list << row;
                     continue;
@@ -719,7 +700,8 @@ void MainWindow::on_radioDesktop1_clicked()
             }
             if (!lua_block_comment) {
                 if (trow.startsWith(block_comment_start)) {
-                    if (debug) qDebug() << "Lua block comment 'STARTS WITH LINE' found" ;
+                    if (debug)
+                        qDebug() << "Lua block comment 'STARTS WITH LINE' found";
                     lua_block_comment = true;
                     new_list << row;
                     continue;
@@ -729,10 +711,10 @@ void MainWindow::on_radioDesktop1_clicked()
                     QStringList ltrow = trow.split(block_comment_start);
                     trow = ltrow[0];
                     trow = trow.trimmed();
-                    if (debug) qDebug() << "Lua block comment start CONTAINS line found: before start --[[: " << trow ;
+                    if (debug)
+                        qDebug() << "Lua block comment start CONTAINS line found: before start --[[: " << trow;
                 }
             }
-
         }
         // comment line
         if (trow.startsWith(comment_sep)) {
@@ -745,23 +727,32 @@ void MainWindow::on_radioDesktop1_clicked()
             continue;
         } else {
 
-            if (debug) qDebug() << "on_radioDesktops1_clicked: own_window_hints found row : " << row ;
-            if (debug) qDebug() << "on_radioDesktops1_clicked: own_window_hints found trow: " << trow ;
+            if (debug)
+                qDebug() << "on_radioDesktops1_clicked: own_window_hints found row : " << row;
+            if (debug)
+                qDebug() << "on_radioDesktops1_clicked: own_window_hints found trow: " << trow;
             match_owh = regexp_owh.match(row);
-            if (match_owh.hasMatch() && match_owh.captured(QStringLiteral("item")) == QLatin1String("own_window_hints") ) {
+            if (match_owh.hasMatch()
+                && match_owh.captured(QStringLiteral("item")) == QLatin1String("own_window_hints")) {
                 QString owh_value = match_owh.captured(QStringLiteral("value"));
-                owh_value.replace(QLatin1String(",sticky"),QLatin1String(""));
-                owh_value.replace(QLatin1String("sticky"),QLatin1String(""));
-                QString new_row = match_owh.captured(QStringLiteral("before")) + owh_value + match_owh.captured(QStringLiteral("after"));
-                if (debug) qDebug() << "Removed sticky: " << new_row ;
+                owh_value.replace(QLatin1String(",sticky"), QLatin1String(""));
+                owh_value.replace(QLatin1String("sticky"), QLatin1String(""));
+                QString new_row = match_owh.captured(QStringLiteral("before")) + owh_value
+                                  + match_owh.captured(QStringLiteral("after"));
+                if (debug)
+                    qDebug() << "Removed sticky: " << new_row;
                 new_list << new_row;
             } else {
-                if (debug) qDebug() << "ERROR : " << row ;
+                if (debug)
+                    qDebug() << "ERROR : " << row;
                 if (is_lua_format) {
-                    if (debug) qDebug() << "regexp_owh : " << regexp_lua_owh ;
-                    if (debug) qDebug() << "regexp_owh : " << regexp_owh ;
+                    if (debug)
+                        qDebug() << "regexp_owh : " << regexp_lua_owh;
+                    if (debug)
+                        qDebug() << "regexp_owh : " << regexp_owh;
                 } else {
-                    if (debug) qDebug() << "regexp_owh : " << regexp_old_owh ;
+                    if (debug)
+                        qDebug() << "regexp_owh : " << regexp_old_owh;
                 }
                 new_list << row;
             }
@@ -783,8 +774,8 @@ void MainWindow::on_radioAllDesktops_clicked()
     QString conky_config_old_end = QStringLiteral("TEXT");
     QString conky_config_end;
     QString conky_sticky;
-    bool lua_block_comment = false;
-    bool conky_config;
+    bool lua_block_comment {false};
+    bool conky_config {false};
 
     if (is_lua_format) {
         regexp_owh = regexp_lua_owh;
@@ -810,7 +801,8 @@ void MainWindow::on_radioAllDesktops_clicked()
             if (lua_block_comment) {
                 if (trow.endsWith(block_comment_end)) {
                     lua_block_comment = false;
-                    if (debug) qDebug() << "Lua block comment end 'ENDS WITH LINE' found" ;
+                    if (debug)
+                        qDebug() << "Lua block comment end 'ENDS WITH LINE' found";
                     new_list << row;
                     continue;
                 }
@@ -820,7 +812,8 @@ void MainWindow::on_radioAllDesktops_clicked()
                     ltrow.removeFirst();
                     trow = ltrow.join(block_comment_end);
                     trow = trow.trimmed();
-                    if (debug) qDebug() << "Lua block comment end CONTAINS line found: after ]]: " << trow ;
+                    if (debug)
+                        qDebug() << "Lua block comment end CONTAINS line found: after ]]: " << trow;
                 } else {
                     new_list << row;
                     continue;
@@ -828,7 +821,8 @@ void MainWindow::on_radioAllDesktops_clicked()
             }
             if (!lua_block_comment) {
                 if (trow.startsWith(block_comment_start)) {
-                    if (debug) qDebug() << "Lua block comment 'STARTS WITH LINE' found" ;
+                    if (debug)
+                        qDebug() << "Lua block comment 'STARTS WITH LINE' found";
                     lua_block_comment = true;
                     new_list << row;
                     continue;
@@ -838,7 +832,8 @@ void MainWindow::on_radioAllDesktops_clicked()
                     QStringList ltrow = trow.split(block_comment_start);
                     trow = ltrow[0];
                     trow = trow.trimmed();
-                    if (debug) qDebug() << "Lua block comment start CONTAINS line found: before start --[[: " << trow ;
+                    if (debug)
+                        qDebug() << "Lua block comment start CONTAINS line found: before start --[[: " << trow;
                 }
             }
         }
@@ -856,7 +851,7 @@ void MainWindow::on_radioAllDesktops_clicked()
             new_list << row;
             continue;
         }
-        if (!conky_config ) {
+        if (!conky_config) {
             new_list << row;
             continue;
         }
@@ -865,26 +860,35 @@ void MainWindow::on_radioAllDesktops_clicked()
             new_list << row;
             continue;
         } else {
-            if (debug) qDebug() << "on_radioAllDesktops_clicked: own_window_hints found row : " << row ;
-            if (debug) qDebug() << "on_radioAllDesktops_clicked: own_window_hints found trow: " << trow ;
+            if (debug)
+                qDebug() << "on_radioAllDesktops_clicked: own_window_hints found row : " << row;
+            if (debug)
+                qDebug() << "on_radioAllDesktops_clicked: own_window_hints found trow: " << trow;
             match_owh = regexp_owh.match(row);
-            if (match_owh.hasMatch() && match_owh.captured(QStringLiteral("item")) == QLatin1String("own_window_hints") ) {
+            if (match_owh.hasMatch()
+                && match_owh.captured(QStringLiteral("item")) == QLatin1String("own_window_hints")) {
                 QString owh_value = match_owh.captured(QStringLiteral("value"));
                 if (owh_value.length() == 0)
                     owh_value = QStringLiteral("sticky");
                 else
                     owh_value.append(",sticky");
-                QString new_row = match_owh.captured(QStringLiteral("before")) + owh_value + match_owh.captured(QStringLiteral("after"));
-                if (debug) qDebug() << "Append sticky: " << new_row ;
+                QString new_row = match_owh.captured(QStringLiteral("before")) + owh_value
+                                  + match_owh.captured(QStringLiteral("after"));
+                if (debug)
+                    qDebug() << "Append sticky: " << new_row;
 
-                new_list << match_owh.captured(QStringLiteral("before")) + owh_value + match_owh.captured(QStringLiteral("after"));
+                new_list << match_owh.captured(QStringLiteral("before")) + owh_value
+                                + match_owh.captured(QStringLiteral("after"));
                 found = true;
             } else {
-                if (debug) qDebug() << "ERROR : " << row ;
+                if (debug)
+                    qDebug() << "ERROR : " << row;
                 if (is_lua_format) {
-                    if (debug) qDebug() << "regexp_owh : " << regexp_lua_owh ;
+                    if (debug)
+                        qDebug() << "regexp_owh : " << regexp_lua_owh;
                 } else {
-                    if (debug) qDebug() << "regexp_owh : " << regexp_old_owh ;
+                    if (debug)
+                        qDebug() << "regexp_owh : " << regexp_old_owh;
                 }
                 found = false;
                 new_list << row;
@@ -927,7 +931,4 @@ void MainWindow::on_pushCM_clicked()
     this->show();
 }
 
-void MainWindow::closeEvent(QCloseEvent *)
-{
-    settings.setValue(QStringLiteral("geometery"), saveGeometry());
-}
+void MainWindow::closeEvent(QCloseEvent * /*event*/) { settings.setValue(QStringLiteral("geometery"), saveGeometry()); }
